/*
 * libgpephone
 *
 * Widget and utility library for GPE Phone Edition.
 * 
 * (c) kernel concepts 2006, 2007
 * 
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef _GPE_SKWINDOW_H
#define _GPE_SKWINDOW_H

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif

#define DBUS_APPLAUNCHER_SERVICE_NAME "org.gpe.applauncher"
#define DBUS_APPLAUNCHER_SOFTKEYS_PATH "/org/gpe/applauncher/softkeys"
#define DBUS_APPLAUNCHER_SOFTKEYS_INTERFACE "org.gpe.applauncher.softkeys"
#define DBUS_APPLAUNCHER_MSG_PATH "/org/gpe/applauncher/msg"
#define DBUS_APPLAUNCHER_MSG_INTERFACE "org.gpe.applauncher.msg"

#define GPE_TYPE_SKWINDOW             (gpe_skwindow_get_type ())
#define GPE_SKWINDOW(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GPE_TYPE_SKWINDOW, GpeSKWindow))
#define GPE_SKWINDOW_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GPE_TYPE_SKWINDOW, GpeSKWindowClass))
#define GPE_IS_SKWINDOW(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GPE_TYPE_SKWINDOW))
#define GPE_IS_SKWINDOW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GPE_SKWINDOW))
#define GPE_SKWINDOW_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GPE_TYPE_SKWINDOW, GpeSKWindowClass))
	
typedef struct _GpeSKWindow      GpeSKWindow;
typedef struct _GpeSKWindowClass GpeSKWindowClass;

struct _GpeSKWindow
{
  /*< public >*/

  /*< private >*/
  GtkWindow window;
  gint num_softkeys;
};

struct _GpeSKWindowClass
{
  GtkWindowClass parent_class;

  void (* softkey_activated) (GpeSKWindow *window, gint key_number);
  void (* menu_down) (GpeSKWindow *window, gint key_number);
  guint (* softkey_count) (GpeSKWindow *window);
  void (* close) (GpeSKWindow *window);
  G_CONST_RETURN gchar* (* get_softkey_label) (GpeSKWindow *window, gint key_number);
  void (* set_softkey_label) (GpeSKWindow *window, gint key_number, const gchar *label);
  void (* set_softkey_menu) (GpeSKWindow *window, gint key_number, GtkWidget *menu);
  GtkWidget * (* get_softkey_menu) (GpeSKWindow *window, gint key_number);
  void (* softkey_popup_menu) (GpeSKWindow *window, gint key_number);

    /* Padding for future expansion */
  void (*_gtk_reserved1) (void);
  void (*_gtk_reserved2) (void);
  void (*_gtk_reserved3) (void);
  void (*_gtk_reserved4) (void);
};


GType      gpe_skwindow_get_type (void) G_GNUC_CONST;
GtkWidget* gpe_skwindow_new      (void);

/* emit softkey activation signal */
void gpe_skwindow_softkey_activated (GpeSKWindow *window, gint key_number);

/* get amount of softkeys */
guint gpe_skwindow_get_softkey_count (GpeSKWindow *window);

G_CONST_RETURN gchar *gpe_skwindow_get_softkey_label (GpeSKWindow *window, gint key_number);
void gpe_skwindow_set_softkey_label (GpeSKWindow *window, gint key_number, const gchar *label);
void gpe_skwindow_set_softkey_menu (GpeSKWindow *window, gint key_number, GtkWidget *menu);
GtkWidget *gpe_skwindow_get_softkey_menu (GpeSKWindow *window, gint key_number);
void gpe_skwindow_softkey_popup_menu (GpeSKWindow *window, gint key_number);
void gpe_skwindow_set_menu_fullscreen(gboolean full); 

#ifdef __cplusplus
}
#endif

#endif
